﻿using Syncfusion.XForms.PopupLayout;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;

namespace SFDataGrid
{
    public partial class MainPage : ContentPage
    {
        ListView listView;
        public MainPage()
        {
            InitializeComponent();

            dataGrid.ItemsSource = new ViewModel().OrdersInfo;
            popupLayout.Closed += PopupLayout_Closed;
        }

        private void PopupLayout_Closed(object sender, EventArgs e)
        {
            foreach (var column in dataGrid.Columns)
            {
                column.IsHidden = true;
            }

            foreach (var column in dataGrid.Columns)
            {
                foreach (var hide in listView.ItemsSource as ObservableCollection<ListViewModel>)
                {
                    if (hide.Selected && column.MappingName == hide.Names)
                    {
                        if (column.IsHidden)
                        {
                            column.IsHidden = false;
                        }
                    }
                }
            }
        }

        private void DataGrid_GridLoaded(object sender, Syncfusion.SfDataGrid.XForms.GridLoadedEventArgs e)
        {
            foreach (var name in dataGrid.Columns)
            {
                ViewModel.ListViewSource.Add(new ListViewModel() { Names = name.MappingName, Selected = true });
            }

            listView = new ListView();
            listView.ItemsSource = ViewModel.ListViewSource;
            listView.ItemTemplate = new DataTemplate(() =>
            {
                StackLayout layout = new StackLayout() { Orientation = StackOrientation.Horizontal };

                Grid grid = new Grid();
                var name = new Label() { HorizontalOptions = LayoutOptions.FillAndExpand};
                var selected = new Switch() { OnColor = Color.Red };

                name.SetBinding(Label.TextProperty, new Binding("Names"));

                selected.SetBinding(Switch.IsToggledProperty, new Binding("Selected"));

                layout.Children.Add(name);
                layout.Children.Add(selected);

                return new ViewCell() { View = layout};
            });

            popupLayout.PopupView.ContentTemplate = new DataTemplate(() =>
        {
            return listView;
        });

            popupLayout.PopupView.HeaderTitle = "Column Chooser";
            popupLayout.PopupView.WidthRequest = 300;
            popupLayout.PopupView.HeightRequest = 500;

        }
        
        private void DataGrid_GridLongPressed(object sender, Syncfusion.SfDataGrid.XForms.GridLongPressedEventArgs e)
        {
            popupLayout.Show();
        }
    }
}
